==> ocaml-mad_0.1.2.orig.tar.gz: ocaml-mad-0.1.2/src/mad.ml <==
(* 
   Copyright 2003 Savonet team

   This file is part of Ocaml-mad.
   
   Ocaml-mad is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.
   
   Ocaml-mad is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public License
   along with Ocaml-mad; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*)

(**
  Functions for decoding mp3 files using libmad.

  @author Samuel Mimram
*)

(* $Id: mad.ml,v 1.12 2004/05/30 20:19:26 jcristau Exp $ *)

type mad_file

exception Mad_error of string
exception Read_error of string
exception End_of_stream
exception Openfile_error of string
exception Closefile_error of string

let _ =
  Callback.register_exception "mad_exn_mad_error" (Mad_error "");
  Callback.register_exception "mad_exn_read_error" (Read_error "");
  Callback.register_exception "mad_exn_end_of_stream" End_of_stream;
  Callback.register_exception "mad_exn_openfile_error" (Openfile_error "");
  Callback.register_exception "mad_exn_closefile_error" (Closefile_error "")

external openfile : string -> mad_file = "ocaml_openfile"

external close : mad_file -> unit = "ocaml_close"

external get_current_position : mad_file -> int = "ocaml_get_current_position"

external decode_frame : mad_file -> string = "ocaml_decode_frame"

let wav_output_channels = 2
let wav_output_sample_freq = 44100
let wav_output_sample_size = 16
let wav_output_big_endian = false
let wav_output_signed = true

==> ocaml-mad_0.1.3.orig.tar.gz: ocaml-mad-0.1.3/src/mad.ml <==
(* 
   Copyright 2003 Savonet team

   This file is part of Ocaml-mad.
   
   Ocaml-mad is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.
   
   Ocaml-mad is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public License
   along with Ocaml-mad; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*)

(**
  Functions for decoding mp3 files using libmad.

  @author Samuel Mimram
*)

(* $Id: mad.ml,v 1.13 2005/03/03 10:52:59 jcristau Exp $ *)

type mad_file

exception Mad_error of string
exception Read_error of string
exception End_of_stream
exception Openfile_error of string
exception Closefile_error of string

let _ =
  Callback.register_exception "mad_exn_mad_error" (Mad_error "");
  Callback.register_exception "mad_exn_read_error" (Read_error "");
  Callback.register_exception "mad_exn_end_of_stream" End_of_stream;
  Callback.register_exception "mad_exn_openfile_error" (Openfile_error "");
  Callback.register_exception "mad_exn_closefile_error" (Closefile_error "")

external openfile : string -> mad_file = "ocaml_mad_openfile"

external close : mad_file -> unit = "ocaml_mad_close"

external get_current_position : mad_file -> int = "ocaml_mad_get_current_position"

external decode_frame : mad_file -> string = "ocaml_mad_decode_frame"

let wav_output_channels = 2
let wav_output_sample_freq = 44100
let wav_output_sample_size = 16
let wav_output_big_endian = false
let wav_output_signed = true
